#ifndef _TASMMATH_CPP_
#define _TASMMATH_CPP_

#include "allegro.h"
#include "tasmMath.h"

fixed calcAngle (const fixed & fromX, const fixed & fromY, const fixed & toX, const fixed & toY, const fixed & currAngle)
{
  //calculates angle between two points. This is relative to the screen's axis.
  //This is also relative to allegro's angles ie 0 = up, 64 = right, 128 = down, 192 = left
  // screen: positive y on bottom, positive x on right, angle forms from negative y axis and rotates to positive x axis
  //cartesian: positive y on top, positive x on right, angle forms from positive x axis and rotates to positive y axis
  //to translate: x -> y', y -> -x'

  fixed ans;

  fixed deltaY = toY - fromY;
  fixed deltaX = fromX - toX;

  if (deltaY == 0 && deltaX == 0)
    return currAngle;
  if (deltaY == 0 && deltaX < 0)
    return itofix (192);
  if (deltaY == 0 && deltaX > 0)
    return itofix (64);

  ans = fixatan (fixdiv (deltaX, deltaY));

  if (deltaY > 0)
    ans -= itofix (128);

  return ans;
}

fixed calcDist (const fixed & fromX, const fixed & fromY, const fixed & toX, const fixed & toY)
{
  //gets the total dist between two points.

  fixed deltaY = toY - fromY;
  fixed deltaX = toX - fromX;

  return fixhypot (deltaX, deltaY);
}
#endif
